@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AutoCorrectionListWidget_H
-#define AutoCorrectionListWidget_H
+#pragma once
 
 #include <QListWidget>
 
@@ -26,4 +25,3 @@ Q_SIGNALS:
 };
 }
 
-#endif // AutoCorrectionListWidget_H
