@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -29,9 +29,7 @@ AutoCorrectionTest::AutoCorrectionTest()
     PimCommon::PimCommonSettings::self()->load();
 }
 
-AutoCorrectionTest::~AutoCorrectionTest()
-{
-}
+AutoCorrectionTest::~AutoCorrectionTest() = default;
 
 void AutoCorrectionTest::shouldHaveDefaultValue()
 {
@@ -522,7 +520,7 @@ void AutoCorrectionTest::shouldAddNonBreakingSpace_data()
     QTest::newRow("onecharacter") << QStringLiteral(":") << QStringLiteral(":") << QStringLiteral("fr") << true;
     QTest::newRow("onecharacter2") << QStringLiteral(" ") << QStringLiteral(" ") << QStringLiteral("fr") << true;
     QTest::newRow("percentage") << QStringLiteral("50 %") << QStringLiteral("50b%") << QStringLiteral("fr") << true;
-    QTest::newRow("degres") << QStringLiteral("50 °C") << QStringLiteral("50b°C") << QStringLiteral("fr") << true;
+    QTest::newRow("degrees") << QStringLiteral("50 °C") << QStringLiteral("50b°C") << QStringLiteral("fr") << true;
     QTest::newRow("simplespace") << QStringLiteral(" ") << QStringLiteral(" ") << QStringLiteral("fr") << true;
 }
 
