@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef RICHTEXTEDITWITHAUTOCORRECTION_H
-#define RICHTEXTEDITWITHAUTOCORRECTION_H
+#pragma once
 
 #include "pimcommon_export.h"
 #include <KPIMTextEdit/RichTextEditor>
@@ -35,8 +34,7 @@ protected:
     void keyPressEvent(QKeyEvent *e) override;
 
 private:
-    RichTextEditWithAutoCorrectionPrivate *const d;
+    std::unique_ptr<RichTextEditWithAutoCorrectionPrivate> const d;
 };
 }
 
-#endif // RICHTEXTEDITWITHAUTOCORRECTION_H
