@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class PluginUtilTest : public QObject
     Q_OBJECT
 public:
     explicit PluginUtilTest(QObject *parent = nullptr);
-    ~PluginUtilTest();
+    ~PluginUtilTest() override;
 private Q_SLOTS:
     void shouldTestIsEnabled_data();
     void shouldTestIsEnabled();
