@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class LogActivitiesDialogTest : public QObject
     Q_OBJECT
 public:
     explicit LogActivitiesDialogTest(QObject *parent = nullptr);
-    ~LogActivitiesDialogTest();
+    ~LogActivitiesDialogTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldClearLog();
