@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <QStandardPaths>
+#include "logactivitiesmainwidget.h"
 #include <QApplication>
 #include <QCommandLineParser>
-#include "logactivitiesmainwidget.h"
+#include <QStandardPaths>
 
 int main(int argc, char **argv)
 {
@@ -19,7 +19,7 @@ int main(int argc, char **argv)
 
     parser.process(app);
 
-    auto *w = new LogActivitiesMainWidget;
+    auto w = new LogActivitiesMainWidget;
     w->show();
     app.exec();
     return 0;
