@@ -1,17 +1,15 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef GOOGLETRANSLATOR_H
-#define GOOGLETRANSLATOR_H
+#pragma once
 
 #include <QNetworkReply>
 #include <QObject>
 class QNetworkAccessManager;
 class QComboBox;
-class QNetworkReply;
 
 namespace PimCommon
 {
@@ -55,4 +53,3 @@ private:
 };
 }
 
-#endif // GOOGLETRANSLATOR_H
