@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KPIMPRINTPREVIEWDIALOG_H
-#define KPIMPRINTPREVIEWDIALOG_H
+#pragma once
 
 #include "pimcommon_export.h"
 #include <QPrintPreviewDialog>
@@ -22,7 +21,7 @@ class PIMCOMMON_EXPORT KPimPrintPreviewDialog : public QPrintPreviewDialog
 public:
     explicit KPimPrintPreviewDialog(QWidget *parent = nullptr);
     explicit KPimPrintPreviewDialog(QPrinter *printer, QWidget *parent = nullptr);
-    ~KPimPrintPreviewDialog();
+    ~KPimPrintPreviewDialog() override;
 
 private:
     void readConfig();
@@ -30,4 +29,3 @@ private:
 };
 }
 
-#endif // KPIMPRINTPREVIEWDIALOG_H
