@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ADDRESSEELINEEDITAKONADI_H
-#define ADDRESSEELINEEDITAKONADI_H
+#pragma once
 
 namespace Akonadi
 {
@@ -31,4 +30,3 @@ private:
 };
 }
 
-#endif // ADDRESSEELINEEDITAKONADI_H
