@@ -1,12 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef BLACKLISTBALOOEMAILSEARCHJOBTEST_H
-#define BLACKLISTBALOOEMAILSEARCHJOBTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -15,10 +14,9 @@ class BlackListBalooEmailSearchJobTest : public QObject
     Q_OBJECT
 public:
     explicit BlackListBalooEmailSearchJobTest(QObject *parent = nullptr);
-    ~BlackListBalooEmailSearchJobTest();
+    ~BlackListBalooEmailSearchJobTest() override;
 
 private Q_SLOTS:
     void shouldNotSearchWhenTextIsEmpty();
 };
 
-#endif // BLACKLISTBALOOEMAILSEARCHJOBTEST_H
