@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,6 +8,7 @@
 
 #include "pimcommonakonadi_export.h"
 #include <QObject>
+#include <memory>
 
 namespace PimCommon
 {
@@ -30,7 +31,7 @@ public:
     QVector<PimCommon::AddressessLineEditAbstractPlugin *> pluginsList() const;
 
 private:
-    AddressessLineEditPluginManagerPrivate *const d;
+    std::unique_ptr<AddressessLineEditPluginManagerPrivate> const d;
 };
 }
 
