@@ -1,11 +1,10 @@
 /*  This file is part of the KDE project
-    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PIMCOMMONAKONADIPRIVATE_EXPORT_H
-#define PIMCOMMONAKONADIPRIVATE_EXPORT_H
+#pragma once
 
 #include "pimcommonakonadi_export.h"
 
@@ -18,4 +17,3 @@
 #define PIMCOMMONAKONADI_TESTS_EXPORT
 #endif
 
-#endif
